#############################################
## Testing the METABOLIC THEORY OF ECOLOGY ##
#############################################

# Marco Plebani, 19/12/2014
# marcoplebani85@gmail.com

rm(list=ls()) # clean R memory



####################################
# Lactin-2 model (Lactin et al. 1995):
####################################

# response = exp(alpha*Temperature) - exp(alpha*Tmax - beta*(Tmax-Temperature)) + gamma

# Where:
# Tmax is the maximum temperature at which the biological response variable is > 0
# alpha contributes to determine the magnitude of response at Toptim, as well as Toptim
# beta contributes to determine Toptim, as well as the steepness of the drop from Toptim to Tmax

dd <- data.frame(Temperature = seq(0,45, by=0.01))
alpha= c(0.09) # contributes to determine the magnitude of response at Toptim, as well as Toptim
Tmax= 40
beta= c(1) # contributes to determine Toptim, as well as the steepness of the drop from Toptim to Tmax
gamma = c(-1) # contributes to determine the magnitude of response at Toptim, as well as the steepness of the increase of the response from Temperature<Toptim towards Toptim. It does not affect Toptim.
dd$response = exp(alpha*dd$Temperature) - exp(alpha*Tmax - beta*(Tmax-dd$Temperature)) + gamma

par(tcl=0.25, family="Times",cex.lab=1.2)
plot(response~Temperature, data=dd, ylim=c(0,50), type="l", xaxt="n", yaxt="n", 
xlab="Temperature", ylab="Biological response (e.g. growth rate)",
main="Lactin-2 model")
axis(2,c(0), c("0"))
text(2,2, "Tmin"); text(42,2, "Tmax"); text(38,28, "Topt")
arrows(0,33,38,33, angle=90, code=3, length=0.1)
text(19,35, "Region where we can test the Metabolic Theory of Ecology")

#####################################################
# Response of of Bacillus phantasticus to temperature
#####################################################

# Load the growth rates of Bacillus phantasticus:
dat <- read.csv("~/Desktop/testing_MTE.csv")[,-1]
str(dat)

# y values are the observed intrinsic population growth rates. Two replicates per temperature.
# Transform temperatures in Kelvin from Celsius:
dat$Kelvin <- dat$Temperature + 273.15

# FIRST OF ALL, plot the untransformed y over temperature:
quartz()
par(tcl=0.25, family="Times",cex.lab=1.2)
plot(y~ Kelvin, data=dat, ylim=c(0,2.5),
	ylab="Growth rate", xlab="Temperature (Kelvin)")
#If you notice that your y increases with temperature only up to a threshold, you will have to fit the model only up to that threshold.
# A way to identify the threshold is to use segmented regression.

library(segmented) #? segmented
lm1 <- lm(y~ Kelvin, data=dat)
oo <- segmented(lm1,seg.Z=~ Kelvin,
			psi=list(Kelvin =c(290.15)),
			# psi allows you to specify one or more values of x, "Kelvin" in this case,
			# where the break is more likely to be found. Here I suggested psi = 290.15 Kelvin
			# (17°C); you choose it based on the graphical evidence.
    		control=seg.control(display=FALSE))
# check:
plot(oo, add=T, lty="dotted", col="grey")
    		
# now we can fit the MTE model using function nls().
# First, define:
boltz <- 0.00008617343 # Boltzmann const.
T.ref<- 15 + 273.15 # so that the pre-exponent "A" is given for temperature = 15°C and not for the absolute zero (0 K). 

start.pars <- c(pre.exp=1, aer=0.67) # starting points for nls() to start searching the parameters from

nls1 <- nls(y ~ pre.exp * exp(aer*(Kelvin - T.ref)/(boltz*Kelvin*T.ref)), 
			start=list(pre.exp= start.pars[1], aer= start.pars[2]),
			data=dat[dat$Kelvin < 293.3,]
			)

summary(nls1)

#To plot the predicted curve on your data,
newX <- expand.grid(Kelvin = seq(
								min(dat$Kelvin),
								293.3, # or max(dat$Kelvin),
								by=0.1)
								)

newY <- predict(nls1,
				newX
				)

quartz()
par(tcl=0.25, family="Times",cex.lab=1.2)
plot(y~ Kelvin, data=dat, ylim=c(0,2.5),
	ylab="growth rate", xlab="Temperature (Kelvin)")				
points(newY ~ newX$Kelvin, type="l", lwd=2)



